package cn.fw.hermes.domain.dto;

import cn.fw.hermes.common.constant.MsgBody;
import cn.fw.hermes.domain.db.SysMsg;
import cn.fw.hermes.sdk.api.para.*;
import com.alibaba.fastjson.JSON;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;


/**
 * @Author: Chenery
 * @Date: 2021/1/29 16:50
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
public class MsgBodyDto {
    /**
     * 发送人
     */
    private String fromAccount;

    /**
     * 接收人
     */
    private String toAccount;

    /**
     * 消息类型
     */
    private MsgTypeEnum msgTypeEnum;
    /**
     * 消息体对象
     */
    private MsgBody msgBody;



    public MsgBodyDto(MsgParamCondition msgPara) {
        msgBody = new MsgBody();
        this.msgTypeEnum = msgPara.getMsgTypeEnum();
        switch (msgPara.getMsgTypeEnum()) {
            case FACE:
                FaceContent faceContent = msgPara.getFaceContent();
                this.msgBody.setData(faceContent.getData());
                this.msgBody.setIndex(faceContent.getIndex());
                break;
            case TEXT:
                TextContent textContent = msgPara.getTextContent();
                this.msgBody.setText(textContent.getText());
                break;
            case LOCATION:
                LocationContent locationContent = msgPara.getLocationContent();
                this.msgBody.setLat(locationContent.getLat());
                this.msgBody.setLng(locationContent.getLng());
                this.msgBody.setDesc(locationContent.getDesc());
                break;
            case CUSTOM:
                CustomContent customContent = msgPara.getCustomContent();
                this.msgBody.setDesc(customContent.getDesc());
                this.msgBody.setData(customContent.getData());
                this.msgBody.setExt(JSON.toJSONString(customContent.getExt()));
                break;
            default: ;


        }
    }


    /**
     * 返回一个消息DB对象
     * @param
     * @return
     */
    public SysMsg getSysMsg(){
        SysMsg sysMsg = new SysMsg();
        if (this.getMsgBody() != null) {
            sysMsg.setMsgText(this.getMsgBody().getText());
            sysMsg.setLat(this.getMsgBody().getLat());
            sysMsg.setLng(this.getMsgBody().getLng());
            sysMsg.setMsgIndex(this.getMsgBody().getIndex());
            sysMsg.setMsgData(this.getMsgBody().getData());
            sysMsg.setExt(this.getMsgBody().getExt());
        }
        sysMsg.setMsgType(this.getMsgTypeEnum().getCode());
        sysMsg.setFromAccount(this.getFromAccount());
        sysMsg.setToAccount(this.getToAccount());
        return sysMsg;
    }


}
