package cn.fw.hermes.controller.wechat;

import static cn.fw.common.businessvalidator.Validator.BV;
import static cn.fw.common.web.util.ExceptionHandler.handleException;
import static cn.fw.common.web.util.ResultBuilder.failureWithMessage;
import static cn.fw.common.web.util.ResultBuilder.success;
import static cn.fw.hermes.common.constant.MessageStr.SAVE_FAILURE;

import cn.fw.common.web.auth.LoginAuthBean;
import cn.fw.common.web.auth.PassportAuthBean;
import cn.fw.common.web.auth.annotation.CurrentUser;
import cn.fw.data.base.domain.common.Message;
import cn.fw.hermes.domain.vo.AccountResultVO;
import cn.fw.hermes.service.biz.AccountBizService;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.annotation.IgnoreAuth;
import cn.fw.security.auth.client.enums.AuthType;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.ObjectUtils;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @Author: Chenery
 * @Date: 2021/2/2 11:11
 */
@RestController
@Slf4j
@RequestMapping("/weChat/account")
@RequiredArgsConstructor
@Authorization(AuthType.WECHAT)
public class WeChatAccountController {
    private final AccountBizService accountBizService;

    /**
     * 获取客户用户签名
     * userId 用户ID
     *
     * @return
     */
    @RequestMapping("/getSig")
    @IgnoreAuth
    public Message<AccountResultVO> getSig(@CurrentUser PassportAuthBean user) {
        final String msg = "获取用户签名[/weChat/account/getSig]";
        try {
            BV.isTrue(!ObjectUtils.isEmpty(user) && !ObjectUtils.isEmpty(user.getUserId()) ,"loginUser不存在或者userId为空" );
            Long userId = user.getUserId();
            log.info("{} params[{}]", msg, userId);
            AccountResultVO vo = accountBizService.getLoginSig(userId, false);
            return success(vo, v -> log.info("{} 成功 : result[{}]", msg, v));
        } catch (Exception ex) {
            handleException(ex, e -> log.error("{} 失败: result:[{}]", msg, e.getMessage()));
            return failureWithMessage(SAVE_FAILURE);
        }

    }


}
